Returns ACC (Area Control Centre) and OAC (Oceanic Area Control Centre)
airspace geometries as an sf object for the specified CFMU AIRAC cycle.
Value
An sf object with the following columns:
AC_ID: the AIRAC cycle idAV_AIRSPACE_ID: the airspace identifierMIN_FLIGHT_LEVEL: the minimum flight levelMAX_FLIGHT_LEVEL: the maximum flight levelNAME: the airspace nameCODE: the airspace codeAIRSPACE_TYPE: the airspace type (ACCorOAC)geometry: the airspace polygon geometry
Note
You need to either provide a connection conn that has access to
ENV_SP.AIRSPACE, PRU_STAT_AUA and SWH_MAP or go with the default
which uses PRU_DEV to establish a db_connection().
The sf package is required but only suggested; install it if not available.
See also
airac::cfmu_airac() from the
airac package.
Examples
if (FALSE) { # \dontrun{
acc <- acc_sf(cfmu_airac = "517")
# write to GeoJSON
sf::st_write(acc, "acc-517.geojson", driver = "GeoJSON")
# if you re-use DB connections
conn <- eurocontrol::db_connection("PRU_DEV")
acc <- acc_sf(conn = conn, cfmu_airac = "517")
# ... do something else with conn
# ...
# then manually close the connection to the DB
DBI::dbDisconnect(conn)
} # }